==> hazelcast-all-4.1-sources.jar: com/hazelcast/org/codehaus/janino/package-info.java <==

/*
 * Janino - An embedded Java[TM] com.hazelcast.com.iler
 *
 * Copyright (c) 2013 Arno Unkrig. All rights reserved.
 * Copyright (c) 2015-2016 TIBCO Software Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *    1. Redistributions of source code must retain the above copyright notice, this list of conditions and the
 *       following disclaimer.
 *    2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *       following disclaimer in the documentation and/or other materials provided with the distribution.
 *    3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote
 *       products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * The core of the Janino Java<sup>TM</sup> com.hazelcast.com.iler.
 * <p>
 *   The package com.hazelcast.com.rises a scanner ({@link com.hazelcast.org.codehaus.janino.Scanner}, a parser ({@link com.hazelcast.org.codehaus.janino.Parser})
 *   and a class file library. The parser builds a syntax tree from the "Java.*" classes that represents the parsed
 *   code. The {@link com.hazelcast.org.codehaus.janino.UnitCompiler#com.hazelcast.com.ileUnit} method com.hazelcast.com.iles this syntax tree into a {@link
 *   com.hazelcast.org.codehaus.janino.util.ClassFile} object, which can write Java<sup>TM</sup> bytecode to an "OutputStream".
 * </p>
 * <p>
 *   This package implements the {@code com.hazelcast.org.codehaus.com.hazelcast.com.ons.com.hazelcast.com.iler} API.
 * </p>
 */
@NotNullByDefault
package com.hazelcast.org.codehaus.janino;

import com.hazelcast.org.codehaus.com.hazelcast.com.ons.nullanalysis.NotNullByDefault;

==> hazelcast-all-4.1.1-sources.jar: com/hazelcast/org/codehaus/janino/package-info.java <==

/*
 * Janino - An embedded Java[TM] compiler
 *
 * Copyright (c) 2013 Arno Unkrig. All rights reserved.
 * Copyright (c) 2015-2016 TIBCO Software Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *    1. Redistributions of source code must retain the above copyright notice, this list of conditions and the
 *       following disclaimer.
 *    2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *       following disclaimer in the documentation and/or other materials provided with the distribution.
 *    3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote
 *       products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * The core of the Janino Java<sup>TM</sup> compiler.
 * <p>
 *   The package comprises a scanner ({@link com.hazelcast.org.codehaus.janino.Scanner}, a parser ({@link com.hazelcast.org.codehaus.janino.Parser})
 *   and a class file library. The parser builds a syntax tree from the "Java.*" classes that represents the parsed
 *   code. The {@link com.hazelcast.org.codehaus.janino.UnitCompiler#compileUnit} method compiles this syntax tree into a {@link
 *   com.hazelcast.org.codehaus.janino.util.ClassFile} object, which can write Java<sup>TM</sup> bytecode to an "OutputStream".
 * </p>
 * <p>
 *   This package implements the {@code com.hazelcast.org.codehaus.commons.compiler} API.
 * </p>
 */
@NotNullByDefault
package com.hazelcast.org.codehaus.janino;

import com.hazelcast.org.codehaus.commons.nullanalysis.NotNullByDefault;
